@@ -12,10 +12,12 @@ FilePath: /cp-common/cp_common/utils.py
 Description: 
 """
 
+import base64
 import inspect
 from typing import List, Set, Tuple
 from cp_common.log import logger
 
+
 def parse_host(host: str) -> List[str]:
     return host.split(",")
 
@@ -66,4 +68,13 @@ def get_host_port_from_url(url: str) -> (str, str):
             port = port.split("/")[0]
     except Exception:
         pass
-    return host, port
\ No newline at end of file
+    return host, port
+
+
+def get_basic_auth_str(username, password):
+    temp_str = username + ":" + password
+    # 转成bytes string
+    bytesString = temp_str.encode(encoding="utf-8")
+    # base64 编码
+    encodestr = base64.b64encode(bytesString)
+    return "Basic " + encodestr.decode()
